# coding=utf-8
#
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2019 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT
from __future__ import absolute_import

import sys
import logging

from clcommon.lib.cledition import lve_supported_or_exit
from clcommon.utils import silence_stdout_until_process_exit
from lvestats.lib.cloudlinux_statistics import main
import lvestats.lib.config as config
from lvestats.lib.commons.logsetup import setup_logging
from lvestats.lib.dbengine import make_db_engine


@lve_supported_or_exit
def clstatistics_main():
    try:
        cnf = config.read_config()
        dbengine = make_db_engine(cnf)
        log = setup_logging(cnf, caller_name="CloudLinuxStatistics", file_level=logging.WARNING, console_level=logging.FATAL)
        exitcode = main(dbengine, argv_=sys.argv[1:], server_id=cnf.get('server_id', 'localhost'), log=log)
    except config.ConfigError as ce:
        ce.log_and_exit()
    else:
        silence_stdout_until_process_exit()
        sys.exit(exitcode)


if __name__ == '__main__':
    clstatistics_main()
